@@ -51,6 +51,9 @@ module CTioga2
           # compulsory arguments and a hash containing optional ones.
           attr_accessor :funcall
 
+          # The underlying nameless class
+          attr_accessor :primitive_class
+
           # Creates a TiogaPrimitive object
           def initialize(name, comp, opts = {}, &code)
             @name = name
@@ -111,10 +114,13 @@ module CTioga2
                            desc = nil, &code)
           primitive = TiogaPrimitive.new(name, comp, opts, &code)
           @known_primitives[name] = primitive
+
+          primitive_class = Class.new(TiogaPrimitiveCall)
+          primitive.primitive_class = primitive_class
           
           # Now, create the command
           cmd_args = comp.map do |x|
-            if x.respond_to?(:type)
+            if x.is_a? CmdArg
               x
             else
               CmdArg.new(x)
@@ -123,7 +129,7 @@ module CTioga2
 
           cmd_opts = {}
           for k,v in opts
-            cmd_opts[k] = if v.respond_to?(:type)
+            cmd_opts[k] = if v.is_a? CmdArg
                             v
                           else
                             CmdArg.new(v)
@@ -132,15 +138,17 @@ module CTioga2
 
           cmd_opts['clipped'] = CmdArg.new('boolean')
           cmd_opts['depth'] = CmdArg.new('integer')
+          cmd_opts.merge!(TiogaElement::StyleBaseOptions)
+
           cmd = Cmd.new("draw-#{name}",nil,"--draw-#{name}", 
                         cmd_args, cmd_opts) do |plotmaker, *rest|
             options = rest.pop
-            call = Elements::
-              TiogaPrimitiveCall.new(primitive,
+            call = primitive_class.new(primitive,
                                      rest, options)
+            container = plotmaker.root_object.current_plot
+            call.setup_style(container, options)
             call.last_curve_style = plotmaker.curve_style_stack.last
-            plotmaker.root_object.current_plot.
-              add_element(call)
+            container.add_element(call)
           end
           if ! desc
             desc = "Directly draws #{long_name} on the current plot"
@@ -150,6 +158,7 @@ module CTioga2
                        PrimitiveGroup)
 
           PrimitiveCommands[name] = cmd
+          return primitive_class
         end
 
         # This creates a primitive base on a style object, given a
@@ -164,13 +173,10 @@ module CTioga2
         def self.styled_primitive(name, long_name, comp, style_class, 
                                   style_name, without = [],
                                   additional_options = {},
-                                  set_style_command = nil, # This
-                                                           # could be
-                                                           # removed
+                                  set_style_command = nil,
                                   &code)
           options = style_class.options_hash.without(without)
           options.merge!(additional_options)
-          options['base-style'] = 'text' # the base style name
 
           set_style_command ||= style_name
           desc = <<"EOD"
@@ -179,14 +185,15 @@ For more information on the available options, see the
 {command: define-#{set_style_command}-style} command.
 EOD
 
-          self.primitive(name, long_name, comp, options, desc) do |*all|
+          cls = self.primitive(name, long_name, comp, options, desc) do |*all|
             opts = all.pop
-            st_name = opts['base-style'] || "base"
-            style = Styles::StyleSheet.style_for(style_class,st_name) 
+            style = get_style()
             style.set_from_hash(opts)
             all << style << opts
             code.call(*all)
           end
+          cls.define_style(set_style_command, style_class)
+          return cls
         end
 
 
@@ -251,6 +258,15 @@ EOD
                           head.to_figure_xy(t) ))
         end
 
+        # @todo Do the same thing for arrows...
+        styled_primitive("oriented-line", "oriented-line", 
+                         [ 'point', 'dimension' ],
+                         Styles::OrientedLineStyle,
+                         'oriented-line'
+                  ) do |t, org, dim, style, options|
+          style.draw_oriented_line(t, *org.to_figure_xy(t), dim)
+        end
+
 
         styled_primitive("image", "image", 
                          [ CmdArg.new('text', 'file'), 
@@ -291,7 +307,7 @@ EOD
           ## @todo this is a really ugly hack for passing
           ## last_curve_style around
           $last_curve_style = @last_curve_style
-          primitive.funcall.call(t, *args)
+          instance_exec(t, *args, &primitive.funcall)
         end
         
         DrawingSpecType = 
