@@ -59,6 +59,40 @@ module CTioga2
 
       end
 
+      # This class represents all the stylistic information necessary
+      # to draw a line parallel to a certain direction, indicated by
+      # an angle (default to horizontal)
+      class OrientedLineStyle < StrokeStyle
+        # The angle, in degrees.
+        typed_attribute :angle, 'float'
+
+        # The alignment of the line with respect to the point given.
+        typed_attribute :origin, 'justification'
+
+        # len is a dimension
+        def draw_oriented_line(t, xo, yo, len)
+
+          angle = @angle || 0.0
+
+          dx,dy = *len.to_figure(t, angle)
+
+          case @origin || Tioga::FigureConstants::LEFT_JUSTIFIED
+          when Tioga::FigureConstants::LEFT_JUSTIFIED
+            x1, y1 = xo, yo
+            x2, y2 = xo + dx, yo + dy
+          when Tioga::FigureConstants::CENTERED
+            x1, y1 = xo - 0.5 * dx, yo - 0.5 * dy
+            x2, y2 = xo + 0.5 * dx, yo + 0.5 * dy
+          when Tioga::FigureConstants::RIGHT_JUSTIFIED
+            x1, y1 = xo - dx, yo - dy
+            x2, y2 = xo, yo
+          end
+
+          draw_line(t, x1, y1, x2, y2)
+        end
+        
+      end
+
       # This class represents all the stylistic information to draw a
       # Marker.
       #
@@ -82,6 +116,7 @@ module CTioga2
         # \p override is a hash that can override part of the
         # dictionnary specification.
         def draw_markers_at(t, x, y, override = nil)
+          return if (! @marker || @marker == 'None')
           t.context do
             ## \todo allow custom line types for markers ?
             t.line_type = LineStyles::Solid
@@ -108,54 +143,6 @@ module CTioga2
         end
       end
 
-      # A style that handles drawing a fill.
-      #
-      # \todo add ways to specify complex fills, such as patterned
-      # fills and so on. Those would use clipping the path and base
-      # themselves on the coordinates of the current frame -- or more
-      # nicely use dimensions ? (which would allow to mix both to some
-      # extent ?)
-      #
-      # \todo more attributes ?
-      #
-      # @todo This class should also provide image-based fills, with
-      # CSS-like capacities (scaling, tiling, centering, and so on...)
-      class FillStyle < BasicStyle
-
-        # The color.
-        typed_attribute :color, "color"
-
-        # The transparency
-        typed_attribute :transparency, 'float'
-
-        # Sets up the parameters for the fill. Must be called before
-        # any path drawing.
-        #
-        # \warning You *must* call FillStyle#do_fill for
-        # filling. Directly calling FigureMaker#fill is not a good
-        # idea, as you lose all 'hand-crafted' fills !
-        def setup_fill(t)
-          t.fill_color = @color if @color
-          t.fill_transparency = @transparency if @transparency
-        end
-
-        # Does the actual filling step. Must be used within a context,
-        # as it quite messes up with many things. Must be called after
-        # a call to #setup_fill.
-        def do_fill(t)
-          t.fill
-        end
-
-      end
-
-      # Same as FillStyle, but with additional parameters that handle
-      # how the fill should be applied to curves.
-      class CurveFillStyle < FillStyle
-
-        typed_attribute :close_type, 'fill-until'
-        
-      end
-
     end
   end
 end
