@@ -44,12 +44,12 @@ module CTioga2
         # The vertical alignment 
         typed_attribute :alignment, 'alignment'
 
-        alias_for :valign, :alignment
+        alias_for :valign, :alignment, true
 
         # The horizontal alignment
         typed_attribute :justification, 'justification'
 
-        alias_for :halign, :justification
+        alias_for :halign, :justification, true
 
         # A text width
         typed_attribute :text_width, "dimension-or-no"
@@ -110,6 +110,8 @@ module CTioga2
         # Prepares the dictionnary for use with show_text
         def prepare_show_text_dict(t, text, x_or_loc, y = nil, measure = nil)
           dict = self.hash_for_tioga(t)
+          # get rid of uncommented stuff problems
+          text = "#{text}%\n"
 
           loc = nil
 
