@@ -24,13 +24,25 @@ module CTioga2
       CmdGroup.new('subplots',
                    "Subplots and assimilated",
                    "Subplots and assimilated", 31)
+
+    SFMOpts = {}
+    for w in %w(left right top bottom)
+      SFMOpts[w] = CmdArg.new("dimension")
+    end
     
     SetFrameMarginsCommand = 
       Cmd.new("frame-margins",nil,"--frame-margins", 
               [
                CmdArg.new('frame-margins'),
-              ]) do |plotmaker, margins|
-      
+              ], SFMOpts) do |plotmaker, margins, opts|
+      if margins
+        for w in SFMOpts.keys
+          if opts.key? w
+            dim = margins.send(w)
+            dim.copy_from(opts[w])
+          end
+        end
+      end
       plotmaker.root_object.current_plot.subframe = margins
     end
 
@@ -40,6 +52,15 @@ Sets the margins for the current plot. Margins are the same things as the
 position (such as specified for and inset). Using this within an inset or
 more complex plots might produce unexpected results. The main use of this 
 function is to control the padding around simple plots.
+
+The options override the contents of the margin, which makes it easy
+to set all the dimensions to a given value and just override the ones
+you need to:
+
+# frame-margins 2mm /left=1cm
+
+This sets all the margins around the side to 2mm excepted the left
+one, which means in particular the bottom axis tick labels will be cut.
 EOH
 
     PaddingCommand = 
@@ -92,14 +113,29 @@ size of the text bits around the plot. However, this can be bothersome
 at times, so you can disable that with this command.
 EOH
 
+    RootPlotCommand = 
+      Cmd.new("root-plot",nil,"--root-plot", 
+              [
+              ], Elements::TiogaElement::StyleBaseOptions) do |plotmaker, opts|
+      Log::debug { "Starting a subplot with specs #{box.inspect}" }
+      opts['id'] ||= 'root'
+      plotmaker.root_object.
+        enter_subobject(Elements::Subplot.new(nil,plotmaker.root_object, opts))
+    end
+    
+    RootPlotCommand.describe('Begin root plot',
+                             <<EOD, SubplotsGroup)
+Begins the root plot. This command is only necessary if you want to
+give styling information to the root plot.
+EOD
 
     InsetCommand =         
       Cmd.new("inset",nil,"--inset", 
               [
                CmdArg.new('box'),
-              ]) do |plotmaker, box|
+              ], Elements::TiogaElement::StyleBaseOptions) do |plotmaker, box, opts|
       Log::debug { "Starting a subplot with specs #{box.inspect}" }
-      subplot = plotmaker.root_object.subplot
+      subplot = plotmaker.root_object.subplot(opts)
       subplot.subframe = box
     end
     
@@ -115,9 +151,9 @@ EOD
       Cmd.new("next-inset",nil,"--next-inset", 
               [
                CmdArg.new('box'),
-              ]) do |plotmaker, box|
+              ], Elements::TiogaElement::StyleBaseOptions) do |plotmaker, box,opts|
       plotmaker.root_object.leave_subobject
-      subplot = plotmaker.root_object.subplot
+      subplot = plotmaker.root_object.subplot(opts)
       subplot.subframe = box
     end
     
@@ -141,15 +177,18 @@ Leaves the current subobject.
 EOD
     RegionOptions = {
       'color' => CmdArg.new('color'),
+      'pattern' => CmdArg.new('fill-pattern'),
+      'reversed_pattern' => CmdArg.new('fill-pattern'),
       'transparency' => CmdArg.new('float'),
       'reversed_color' => CmdArg.new('color'),
       'reversed_transparency' => CmdArg.new('float'),
     }
+    RegionOptions.merge!(Elements::TiogaElement::StyleBaseOptions)
 
     RegionCommand =         
       Cmd.new("region",nil,"--region", 
               [ ], RegionOptions) do |plotmaker, options|
-      r = plotmaker.root_object.enter_region
+      r = plotmaker.root_object.enter_region(options)
       r.set_from_hash(options)
     end
     
@@ -163,8 +202,9 @@ EOD
 
     GradientCommand =         
       Cmd.new("gradient",nil,"--gradient", 
-              [CmdArg.new('color'), CmdArg.new('color') ], {}) do |plotmaker, s, e, options|
-      r = plotmaker.root_object.enter_gradient
+              [CmdArg.new('color'), CmdArg.new('color') ], 
+              Elements::TiogaElement::StyleBaseOptions) do |plotmaker, s, e, options|
+      r = plotmaker.root_object.enter_gradient(options)
       r.start_color = s
       r.end_color = e
       r.set_from_hash(options)
@@ -240,6 +280,41 @@ larger than the other ones, while the second row is four times larger
 than the first.
 EOH
 
+
+    ReopenCommand =         
+      Cmd.new("reopen",nil,"--reopen", 
+              [CmdArg.new('object')], {}) do |plotmaker, obj, options|
+      plotmaker.root_object.enter_subobject(obj, false)
+    end
+    
+    ReopenCommand.describe('Reopens a previously finished object',
+                           <<EOD, SubplotsGroup)
+Reopens a previously finished container, such as a subplot, a region
+or a gradient. Provide the unique name you gave as the @/id=@ option
+to the first command
+EOD
+
+    HideCommand = 
+      Cmd.new("hide",nil,"--hide", 
+              [CmdArg.new('objects')], {
+                'show' => CmdArg.new('boolean') 
+              }) do |plotmaker, objs, opts|
+      hidden = if opts.key? 'show'
+                 ! opts['show']
+               else
+                 true
+               end
+      for o in objs
+        o.hidden = hidden
+      end
+    end
+      
+
+    HideCommand.describe('Hides named objects',
+                         <<EOD, SubplotsGroup)
+Hides all the named objects in the list. Useful for creating animations.
+EOD
+
 #     ZoomCommand =         
 #       Cmd.new("zoom-inset",nil,"--zoom-inset", 
 #               [
